summaryrefslogtreecommitdiffstats
path: root/korn/imap_proto.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-09-03 20:02:55 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-09-03 21:02:00 +0200
commit533bad2a1503973aaf8186691422c2eda91d02d4 (patch)
treef7e52f62416048859aa9bde8425e20aac0e7c669 /korn/imap_proto.h
parent8144d5434bbd1c4448a37695aed6ad3d348043d8 (diff)
downloadtdepim-533bad2a1503973aaf8186691422c2eda91d02d4.tar.gz
tdepim-533bad2a1503973aaf8186691422c2eda91d02d4.zip
Additional k => tde renaming and fixes
Diffstat (limited to 'korn/imap_proto.h')
-rw-r--r--korn/imap_proto.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/korn/imap_proto.h b/korn/imap_proto.h
index 4030c5cc..6bd90d40 100644
--- a/korn/imap_proto.h
+++ b/korn/imap_proto.h
@@ -30,10 +30,10 @@
/**
* This class define the way a imap-protocol works.
* It implements function of KIO_Protocol to make the kio-modules work with it,
* as well as function of Protocol, to configure it.
*/
-class Imap_Protocol : public KIO_Protocol
+class Imap_Protocol : public TDEIO_Protocol
{
public:
/**
@@ -30,10 +30,10 @@
/**
* This class define the way a imap-protocol works.
- * It implements function of KIO_Protocol to make the kio-modules work with it,
+ * It implements function of TDEIO_Protocol to make the tdeio-modules work with it,
* as well as function of Protocol, to configure it.
*/